summaryrefslogtreecommitdiff
path: root/scripts/version.sh
diff options
context:
space:
mode:
Diffstat (limited to 'scripts/version.sh')
-rwxr-xr-xscripts/version.sh6
1 files changed, 3 insertions, 3 deletions
diff --git a/scripts/version.sh b/scripts/version.sh
index 46b9fc5..50c189c 100755
--- a/scripts/version.sh
+++ b/scripts/version.sh
@@ -1,11 +1,11 @@
#!/bin/sh
# The yChat Project (2005)
#
# This script shows yChat VERSION-BRANCH Build BUILDNUMBER
version=`grep VERSION src/msgs.h | head -n 1 | cut -d'"' -f2`
branch=`grep BRANCH src/msgs.h | head -n 1 | cut -d'"' -f2`
build=`grep BUILD src/msgs.h | tail -n 1 | cut -d' ' -f3`
-echo "yChat $version-$branch Build $build"
+echo "yhttpd $version-$branch Build $build"
@@ -1,11 +1,11 @@
#!/bin/sh
-# The yChat Project (2005)
+# The yhttpd Project (2005)
#
@@ -1,11 +1,11 @@
#
-# This script shows yChat VERSION-BRANCH Build BUILDNUMBER
+# This script shows yhttpd VERSION-BRANCH Build BUILDNUMBER
version=`grep VERSION src/msgs.h | head -n 1 | cut -d'"' -f2`
branch=`grep BRANCH src/msgs.h | head -n 1 | cut -d'"' -f2`